netapp_ontap.models.aws_kms_ekmip_reachability API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.aws_kms_ekmip_reachability`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class AwsKmsEkmipReachabilitySchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the AwsKmsEkmipReachability object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `code: str GET POST PATCH`

    Code corresponding to the error message. Returns a 0 if a given SVM is able to communicate to the EKMIP servers of all of the nodes in the cluster.

    Example: 346758

  `message: str GET POST PATCH`

    Error message set when cluster-wide EKMIP server availability from the given SVM and node is false.

    Example: embedded KMIP server status unavailable on node.

  `node: Node GET POST PATCH`

    The node field of the aws_kms_ekmip_reachability.

  `reachable: bool GET POST PATCH`

    Set to true if the given SVM on the given node is able to communicate to all EKMIP servers configured on all nodes in the cluster.